==> 0.10.7.tar.gz: lib/widget/vgk_card_horizontal_with_popup_widget/vgk_card_horizontal_with_popup_widget.dart <==
import 'package:cached_network_image/cached_network_image.dart';
import 'package:flutter/material.dart';
import 'package:vgkprogaming/model/vgk_card_horizontal_with_popup_model.dart';
import 'package:vgkprogaming/theme/vgk_shared_theme.dart';
import 'package:vgkprogaming/widget/vgk_card_horizontal_with_popup_widget/vgk_card_horizontal_with_popup_content_widget.dart';

class VgkCardHorizontalWithPopupWidget extends StatefulWidget {
  const VgkCardHorizontalWithPopupWidget(
      {Key? key,
      required this.mainScreenAnimationController,
      required this.mainScreenAnimation,
      required this.data,
      required this.primaryColor})
      : super(key: key);

  final AnimationController mainScreenAnimationController;
  final Animation<double> mainScreenAnimation;
  final String primaryColor;
  final List<VgkCardHorizontalWithPopupDetailModel> data;
  @override
  _VgkCardHorizontalWithPopupWidgetState createState() =>
      _VgkCardHorizontalWithPopupWidgetState();
}

class _VgkCardHorizontalWithPopupWidgetState
    extends State<VgkCardHorizontalWithPopupWidget>
    with TickerProviderStateMixin {
  late AnimationController animationController;

  @override
  void initState() {
    animationController = AnimationController(
      duration: Duration(milliseconds: VgkProGamingTheme.milliseconds),
      vsync: this,
    );
    super.initState();
  }

  @override
  void dispose() {
    animationController.dispose();
    super.dispose();
  }

  @override
  Widget build(BuildContext context) {
    return AnimatedBuilder(
      animation: widget.mainScreenAnimationController,
      builder: (context, child) {
        return FadeTransition(
          opacity: widget.mainScreenAnimation,
          child: Transform(
            transform: VgkProGamingTheme.transform(widget.mainScreenAnimation),
            child: SizedBox(
              height: 216,
              width: double.infinity,
              child: ListView.builder(
                padding: const EdgeInsets.only(
                    top: 0, bottom: 0, right: 16, left: 16),
                itemCount: widget.data.length,
                scrollDirection: Axis.horizontal,
                itemBuilder: (BuildContext context, int index) {
                  final Animation<dynamic> animation =
                      VgkProGamingTheme.animationOption(animationController);
                  animationController.forward();
                  return CardHorizontalSecondSubWidget(
                    data: widget.data[index],
                    animation: animation as Animation<double>,
                    animationController: animationController,
                    primaryColor: widget.primaryColor,
                  );
                },
              ),
            ),
          ),
        );
      },
    );
  }
}

class CardHorizontalSecondSubWidget extends StatelessWidget {
  const CardHorizontalSecondSubWidget(
      {Key? key,
      required this.data,
      required this.animationController,
      required this.animation,
      required this.primaryColor})
      : super(key: key);

  final VgkCardHorizontalWithPopupDetailModel data;
  final AnimationController animationController;
  final Animation<double> animation;
  final String primaryColor;

  List<String> getSubCategory(String name) {
    if (name == "Camera Sensitivity") {
      return [
        '3rd Person Camera,',
        'Camera,',
        '1rd Person Camera,',
      ];
    } else if (name == "Camera") {
      return [
        'Red Dot,',
        'Holographic,',
        'Aim Assist',
      ];
    } else if (name == "Gyroscope Sensitivity") {
      return [
        'Red Dot,',
        'Holographic,',
        'Aim Assist',
      ];
    } else {
      return [
        'No Scope',
        'Red Dot,',
        'Holographic,',
        'Aim Assist',
      ];
    }
  }

  @override
  Widget build(BuildContext context) {
    return AnimatedBuilder(
      animation: animationController,
      builder: (context, child) {
        return FadeTransition(
          opacity: animation,
          child: Transform(
            transform: VgkProGamingTheme.subTransform(animation),
            child: SizedBox(
              width: 230,
              child: Stack(children: [
                GestureDetector(
                  onTap: () {
                    vgkCardHorizontalWithPopupContentWidget(
                      context,
                      data.key,
                      data.data,
                      animation,
                      primaryColor,
                    );
                  },
                  child: Stack(
                    children: <Widget>[
                      Padding(
                        padding: const EdgeInsets.only(
                            top: 32, left: 8, right: 8, bottom: 16),
                        child: Container(
                          decoration: VgkProGamingTheme.cardDecorationWithPopUp(
                              primaryColor),
                          child: Padding(
                            padding: const EdgeInsets.only(
                                top: 54, left: 16, right: 16, bottom: 8),
                            child: Column(
                              mainAxisAlignment: MainAxisAlignment.center,
                              crossAxisAlignment: CrossAxisAlignment.start,
                              children: <Widget>[
                                Text(
                                  data.key,
                                  textAlign: TextAlign.center,
                                  style: VgkProGamingTheme.h2White,
                                ),
                                Expanded(
                                  child: Padding(
                                    padding: const EdgeInsets.only(
                                        top: 8, bottom: 8),
                                    child: Row(
                                      mainAxisAlignment:
                                          MainAxisAlignment.start,
                                      crossAxisAlignment:
                                          CrossAxisAlignment.start,
                                      children: <Widget>[
                                        Text(
                                          getSubCategory(data.value).join('\n'),
                                          style: VgkProGamingTheme
                                              .h3WhiteWithOpacity,
                                        ),
                                      ],
                                    ),
                                  ),
                                ),
                                Row(
                                  mainAxisAlignment: MainAxisAlignment.start,
                                  crossAxisAlignment: CrossAxisAlignment.end,
                                  children: <Widget>[
                                    Container(
                                      decoration: BoxDecoration(
                                        color: VgkProGamingTheme.nearlyWhite,
                                        shape: BoxShape.circle,
                                        boxShadow: <BoxShadow>[
                                          BoxShadow(
                                              color: VgkProGamingTheme
                                                  .nearlyBlack
                                                  .withOpacity(0.4),
                                              offset: const Offset(8.0, 8.0),
                                              blurRadius: 8.0),
                                        ],
                                      ),
                                      child: Padding(
                                        padding: const EdgeInsets.all(6.0),
                                        child: Icon(
                                          Icons.add,
                                          color: HexColor(primaryColor),
                                          size: 24,
                                        ),
                                      ),
                                    ),
                                    Padding(
                                      padding: const EdgeInsets.only(
                                          left: 4, bottom: 3),
                                      child: Text(
                                        'more',
                                        style: VgkProGamingTheme
                                            .h3WhiteWithOpacity,
                                      ),
                                    ),
                                  ],
                                )
                              ],
                            ),
                          ),
                        ),
                      ),
                      Positioned(
                        top: 0,
                        left: 0,
                        child: Container(
                          width: 84,
                          height: 84,
                          decoration: BoxDecoration(
                            color:
                                VgkProGamingTheme.nearlyWhite.withOpacity(0.2),
                            shape: BoxShape.circle,
                          ),
                        ),
                      ),
                      Positioned(
                        top: 0,
                        left: 8,
                        child: SizedBox(
                          width: 80,
                          height: 80,
                          child: AspectRatio(
                            aspectRatio: 1.0,
                            child: CachedNetworkImage(
                              imageUrl:
                                  'https://raw.githubusercontent.com/vgkgopalsaroja/progammingasset/main/app1/items/Master.png',
                              progressIndicatorBuilder:
                                  (context, url, downloadProgress) =>
                                      CircularProgressIndicator(
                                          value: downloadProgress.progress),
                              errorWidget: (context, url, error) =>
                                  const Icon(Icons.error),
                            ),
                            // Image.network(data.src),
                          ),
                        ),
                      )
                    ],
                  ),
                )
              ]),
            ),
          ),
        );
      },
    );
  }
}

==> 0.11.0.tar.gz: lib/widget/vgk_card_horizontal_with_popup_widget/vgk_card_horizontal_with_popup_widget.dart <==
import 'package:cached_network_image/cached_network_image.dart';
import 'package:flutter/material.dart';
import 'package:vgkprogaming/model/vgk_card_horizontal_with_popup_model.dart';
import 'package:vgkprogaming/theme/vgk_shared_theme.dart';
import 'package:vgkprogaming/utils/vgk_common_utils.dart';
import 'package:vgkprogaming/widget/vgk_card_horizontal_with_popup_widget/vgk_card_horizontal_with_popup_content_widget.dart';

class VgkCardHorizontalWithPopupWidget extends StatefulWidget {
  const VgkCardHorizontalWithPopupWidget(
      {Key? key,
      required this.mainScreenAnimationController,
      required this.mainScreenAnimation,
      required this.data,
      required this.primaryColor})
      : super(key: key);

  final AnimationController mainScreenAnimationController;
  final Animation<double> mainScreenAnimation;
  final String primaryColor;
  final List<VgkCardHorizontalWithPopupDetailModel> data;
  @override
  _VgkCardHorizontalWithPopupWidgetState createState() =>
      _VgkCardHorizontalWithPopupWidgetState();
}

class _VgkCardHorizontalWithPopupWidgetState
    extends State<VgkCardHorizontalWithPopupWidget>
    with TickerProviderStateMixin {
  late AnimationController animationController;

  @override
  void initState() {
    animationController = AnimationController(
      duration: Duration(milliseconds: VgkProGamingTheme.milliseconds),
      vsync: this,
    );
    super.initState();
  }

  @override
  void dispose() {
    animationController.dispose();
    super.dispose();
  }

  @override
  Widget build(BuildContext context) {
    return AnimatedBuilder(
      animation: widget.mainScreenAnimationController,
      builder: (context, child) {
        return FadeTransition(
          opacity: widget.mainScreenAnimation,
          child: Transform(
            transform: VgkProGamingTheme.transform(widget.mainScreenAnimation),
            child: SizedBox(
              height: 216,
              width: double.infinity,
              child: ListView.builder(
                padding: const EdgeInsets.only(
                    top: 0, bottom: 0, right: 16, left: 16),
                itemCount: widget.data.length,
                scrollDirection: Axis.horizontal,
                itemBuilder: (BuildContext context, int index) {
                  final Animation<dynamic> animation =
                      VgkProGamingTheme.animationOption(animationController);
                  animationController.forward();
                  return CardHorizontalSecondSubWidget(
                    data: widget.data[index],
                    animation: animation as Animation<double>,
                    animationController: animationController,
                    primaryColor: widget.primaryColor,
                  );
                },
              ),
            ),
          ),
        );
      },
    );
  }
}

class CardHorizontalSecondSubWidget extends StatelessWidget {
  const CardHorizontalSecondSubWidget(
      {Key? key,
      required this.data,
      required this.animationController,
      required this.animation,
      required this.primaryColor})
      : super(key: key);

  final VgkCardHorizontalWithPopupDetailModel data;
  final AnimationController animationController;
  final Animation<double> animation;
  final String primaryColor;

  List<String> getSubCategory(String name) {
    if (name == "Camera Sensitivity") {
      return [
        '3rd Person Camera,',
        'Camera,',
        '1rd Person Camera,',
      ];
    } else if (name == "Camera") {
      return [
        'Red Dot,',
        'Holographic,',
        'Aim Assist',
      ];
    } else if (name == "Gyroscope Sensitivity") {
      return [
        'Red Dot,',
        'Holographic,',
        'Aim Assist',
      ];
    } else {
      return [
        'No Scope',
        'Red Dot,',
        'Holographic,',
        'Aim Assist',
      ];
    }
  }

  @override
  Widget build(BuildContext context) {
    return AnimatedBuilder(
      animation: animationController,
      builder: (context, child) {
        return FadeTransition(
          opacity: animation,
          child: Transform(
            transform: VgkProGamingTheme.subTransform(animation),
            child: SizedBox(
              width: 230,
              child: Stack(children: [
                GestureDetector(
                  onTap: () {
                    vgkCardHorizontalWithPopupContentWidget(
                      context,
                      data.key,
                      data.data,
                      animation,
                      primaryColor,
                    );
                  },
                  child: Stack(
                    children: <Widget>[
                      Padding(
                        padding: const EdgeInsets.only(
                            top: 32, left: 8, right: 8, bottom: 16),
                        child: Container(
                          decoration: VgkProGamingTheme.cardDecorationWithPopUp(
                              primaryColor),
                          child: Padding(
                            padding: const EdgeInsets.only(
                                top: 54, left: 16, right: 16, bottom: 8),
                            child: Column(
                              mainAxisAlignment: MainAxisAlignment.center,
                              crossAxisAlignment: CrossAxisAlignment.start,
                              children: <Widget>[
                                Text(
                                  data.key,
                                  textAlign: TextAlign.center,
                                  style: VgkProGamingTheme.h2White,
                                ),
                                Expanded(
                                  child: Padding(
                                    padding: const EdgeInsets.only(
                                        top: 8, bottom: 8),
                                    child: Row(
                                      mainAxisAlignment:
                                          MainAxisAlignment.start,
                                      crossAxisAlignment:
                                          CrossAxisAlignment.start,
                                      children: <Widget>[
                                        Text(
                                          getSubCategory(data.value).join('\n'),
                                          style: VgkProGamingTheme
                                              .h3WhiteWithOpacity,
                                        ),
                                      ],
                                    ),
                                  ),
                                ),
                                Row(
                                  mainAxisAlignment: MainAxisAlignment.start,
                                  crossAxisAlignment: CrossAxisAlignment.end,
                                  children: <Widget>[
                                    Container(
                                      decoration: BoxDecoration(
                                        color: VgkProGamingTheme.nearlyWhite,
                                        shape: BoxShape.circle,
                                        boxShadow: <BoxShadow>[
                                          BoxShadow(
                                              color: VgkProGamingTheme
                                                  .nearlyBlack
                                                  .withOpacity(0.4),
                                              offset: const Offset(8.0, 8.0),
                                              blurRadius: 8.0),
                                        ],
                                      ),
                                      child: Padding(
                                        padding: const EdgeInsets.all(6.0),
                                        child: Icon(
                                          Icons.add,
                                          color: HexColor(primaryColor),
                                          size: 24,
                                        ),
                                      ),
                                    ),
                                    Padding(
                                      padding: const EdgeInsets.only(
                                          left: 4, bottom: 3),
                                      child: Text(
                                        'more',
                                        style: VgkProGamingTheme
                                            .h3WhiteWithOpacity,
                                      ),
                                    ),
                                  ],
                                )
                              ],
                            ),
                          ),
                        ),
                      ),
                      Positioned(
                        top: 0,
                        left: 0,
                        child: Container(
                          width: 84,
                          height: 84,
                          decoration: BoxDecoration(
                            color:
                                VgkProGamingTheme.nearlyWhite.withOpacity(0.2),
                            shape: BoxShape.circle,
                          ),
                        ),
                      ),
                      Positioned(
                        top: 0,
                        left: 8,
                        child: SizedBox(
                          width: 80,
                          height: 80,
                          child: AspectRatio(
                              aspectRatio: 1.0,
                              child: VgkCommonUtils.imageloader(
                                  'https://raw.githubusercontent.com/vgkgopalsaroja/progammingasset/main/app1/items/Master.png')),
                        ),
                      )
                    ],
                  ),
                )
              ]),
            ),
          ),
        );
      },
    );
  }
}
